**Example 1: 车辆VIN码识别示例代码**



Input: 

```
tccli ocr VinOCR --cli-unfold-argument  \
    --ImageUrl https://xx/a.jpg
```

Output: 
```
{
    "Response": {
        "Vin": "LBV2B25G2E5069977",
        "RequestId": "c59d9002-6c8c-426d-b57f-a8837dee2c7c"
    }
}
```

